@@ -1,12 +1,8 @@
-$:.unshift(File.dirname(__FILE__)) unless
-  $:.include?(File.dirname(__FILE__)) || $:.include?(File.expand_path(File.dirname(__FILE__)))
-
 require 'yaml'
+require 'cucumber/encoding'
 require 'cucumber/platform'
-require 'cucumber/parser'
-require 'cucumber/step_mother'
+require 'cucumber/runtime'
 require 'cucumber/cli/main'
-require 'cucumber/broadcaster'
 require 'cucumber/step_definitions'
 require 'cucumber/term/ansicolor'
 
@@ -24,5 +20,11 @@ module Cucumber
     def logger=(logger)
       @log = logger
     end
+
+    def deprecate(class_name, method, message)
+      return self # deprecation warnings will come in v2.1
+      called_by = caller[1]
+      warn("Deprecated: #{class_name}##{method} #{message}. Caller: #{called_by}")
+    end
   end
 end
