@@ -25,10 +25,8 @@ module Cucumber
         @options.parse!(args)
         arrange_formats
         raise("You can't use both --strict and --wip") if strict? && wip?
-
+        # todo: remove
         @options[:tag_expression] = Gherkin::TagExpression.new(@options[:tag_expressions])
-        return @args.replace(@options.expanded_args_without_drb) if drb?
-
         set_environment_variables
       end
 
@@ -36,6 +34,14 @@ module Cucumber
         @options[:verbose]
       end
 
+      def randomize?
+        @options[:order] == 'random'
+      end
+
+      def seed
+        Integer(@options[:seed] || rand(0xFFFF))
+      end
+
       def strict?
         @options[:strict]
       end
@@ -48,14 +54,6 @@ module Cucumber
         @options[:guess]
       end
 
-      def drb?
-        @options[:drb]
-      end
-
-      def drb_port
-        @options[:drb_port].to_i if @options[:drb_port]
-      end
-
       def dry_run?
         @options[:dry_run]
       end
@@ -64,18 +62,10 @@ module Cucumber
         @options[:expand]
       end
 
-      def dotcucumber
-        @options[:dotcucumber]
-      end
-
       def snippet_type
         @options[:snippet_type] || :regexp
       end
 
-      def build_tree_walker(runtime)
-        Ast::TreeWalker.new(runtime, formatters(runtime), self)
-      end
-
       def formatter_class(format)
         if(builtin = Options::BUILTIN_FORMATS[format])
           constantize(builtin[0])
@@ -117,7 +107,7 @@ module Cucumber
             Dir["#{path}/**/*.feature"].sort
           elsif path[0..0] == '@' and # @listfile.txt
               File.file?(path[1..-1]) # listfile.txt is a file
-            IO.read(path[1..-1]).split
+            IO.read(path[1..-1]).split(/(.*?\.feature.*?) /).collect(&:strip).reject(&:empty?)
           else
             path
           end
@@ -140,10 +130,23 @@ module Cucumber
         logger
       end
 
+      # todo: remove
       def tag_expression
         Gherkin::TagExpression.new(@options[:tag_expressions])
       end
 
+      def tag_limits
+        tag_expression.limits.to_hash
+      end
+
+      def tag_expressions
+        @options[:tag_expressions]
+      end
+
+      def name_regexps
+        @options[:name_regexps]
+      end
+
       def filters
         @options.filters
       end
@@ -160,27 +163,14 @@ module Cucumber
       def paths
         @options[:paths]
       end
-    private
-      def with_default_features_path(paths)
-        return ['features'] if paths.empty?
-        paths
-      end
-
-
-      def formatters(runtime)
-        # TODO: We should remove the autoformat functionality. That
-        # can be done with the gherkin CLI.
-        if @options[:autoformat]
-          require 'cucumber/formatter/pretty'
-          return [Formatter::Pretty.new(runtime, out_stream, @options)]
-        end
 
+      def formatter_factories
         @options[:formats].map do |format_and_out|
           format = format_and_out[0]
           path_or_io = format_and_out[1]
           begin
-            formatter_class = formatter_class(format)
-            formatter_class.new(runtime, path_or_io, @options)
+            factory = formatter_class(format)
+            yield factory, path_or_io, @options
           rescue Exception => e
             e.message << "\nError creating formatter: #{format}"
             raise e
@@ -188,13 +178,19 @@ module Cucumber
         end
       end
 
+      private
+
+      def with_default_features_path(paths)
+        return ['features'] if paths.empty?
+        paths
+      end
+
       class LogFormatter < ::Logger::Formatter
         def call(severity, time, progname, msg)
           msg
         end
       end
 
-
       def set_environment_variables
         @options[:env_vars].each do |var, value|
           ENV[var] = value
