@@ -1,6 +1,7 @@
 require 'cucumber/cli/profile_loader'
 require 'cucumber/formatter/ansicolor'
 require 'cucumber/rb_support/rb_language'
+require 'cucumber/project_initializer'
 
 module Cucumber
   module Cli
@@ -27,7 +28,7 @@ module Cucumber
       max = BUILTIN_FORMATS.keys.map{|s| s.length}.max
       FORMAT_HELP = (BUILTIN_FORMATS.keys.sort.map do |key|
         "  #{key}#{' ' * (max - key.length)} : #{BUILTIN_FORMATS[key][1]}"
-      end) + ["Use --format rerun --out features.txt to write out failing",
+      end) + ["Use --format rerun --out rerun.txt to write out failing",
         "features. You can rerun them with cucumber @rerun.txt.",
         "FORMAT can also be the fully qualified class name of",
         "your own custom formatter. If the class isn't loaded,",
@@ -38,8 +39,6 @@ module Cucumber
         "path underneath your features/support directory or anywhere",
         "on Ruby's LOAD_PATH, for example in a Ruby gem."
       ]
-      DRB_FLAG = '--drb'
-      DRB_OPTIONAL_FLAG = '--[no-]drb'
       PROFILE_SHORT_FLAG = '-p'
       NO_PROFILE_SHORT_FLAG = '-P'
       PROFILE_LONG_FLAG = '--profile'
@@ -47,8 +46,9 @@ module Cucumber
       OPTIONS_WITH_ARGS = ['-r', '--require', '--i18n', '-f', '--format', '-o', '--out',
                                   '-t', '--tags', '-n', '--name', '-e', '--exclude',
                                   PROFILE_SHORT_FLAG, PROFILE_LONG_FLAG,
-                                  '-a', '--autoformat', '-l', '--lines', '--port',
+                                  '-l', '--lines', '--port',
                                   '-I', '--snippet-type']
+      ORDER_TYPES = %w{defined random}
 
       def self.parse(args, out_stream, error_stream, options = {})
         new(out_stream, error_stream, options).parse!(args)
@@ -76,43 +76,6 @@ module Cucumber
         @options[key] = value
       end
 
-      def expanded_args_without_drb
-        return @expanded_args_without_drb  if @expanded_args_without_drb
-        @expanded_args_without_drb = (
-          previous_flag_was_profile = false
-          previous_flag_requires_arg = false
-
-          @expanded_args.reject do |arg|
-            # ignore profiles
-            if previous_flag_was_profile
-              previous_flag_was_profile = false
-              next true
-            end
-            if [PROFILE_SHORT_FLAG, PROFILE_LONG_FLAG].include?(arg)
-              previous_flag_was_profile = true
-              next true
-            end
-
-            # accept all options which requires arguments
-            # and don't try to look @overridden_paths in it's arguments!
-            if previous_flag_requires_arg
-              previous_flag_requires_arg = false
-              next false
-            end
-            if OPTIONS_WITH_ARGS.include?(arg)
-              previous_flag_requires_arg = true
-              next false
-            end
-
-            # ignore --drb flag and overridden features paths
-            arg == DRB_FLAG || @overridden_paths.include?(arg)
-          end
-        )
-
-        @expanded_args_without_drb.push("--no-profile") unless @expanded_args_without_drb.include?(NO_PROFILE_LONG_FLAG) || @expanded_args_without_drb.include?(NO_PROFILE_SHORT_FLAG)
-        @expanded_args_without_drb
-      end
-
       def parse!(args)
         @args = args
         @expanded_args = @args.dup
@@ -164,6 +127,12 @@ module Cucumber
             *FORMAT_HELP) do |v|
             @options[:formats] << [v, @out_stream]
           end
+          opts.on('--init',
+            'Initializes folder structure and generates conventional files for',
+            'a Cucumber project.') do |v|
+            ProjectInitializer.new.run
+            Kernel.exit(0)
+          end
           opts.on("-o", "--out [FILE|DIR]",
             "Write output to a file/directory instead of STDOUT. This option",
             "applies to the previously specified --format, or the",
@@ -220,16 +189,6 @@ module Cucumber
             "This also omits the loading of your support/env.rb file if it exists.") do
             @options[:dry_run] = true
           end
-          opts.on("-a", "--autoformat DIR",
-            "Reformats (pretty prints) feature files and write them to DIRECTORY.",
-            "Be careful if you choose to overwrite the originals.",
-            "Implies --dry-run --format pretty.") do |directory|
-            @options[:autoformat] = directory
-            Cucumber::Term::ANSIColor.coloring = false
-            @options[:dry_run] = true
-            @quiet = true
-          end
-
           opts.on("-m", "--no-multiline",
             "Don't print multiline strings and tables under steps.") do
             @options[:no_multiline] = true
@@ -271,14 +230,17 @@ module Cucumber
           opts.on("-x", "--expand", "Expand Scenario Outline Tables in output.") do
             @options[:expand] = true
           end
-          opts.on(DRB_OPTIONAL_FLAG, "Run features against a DRb server. (i.e. with the spork gem)") do |drb|
-            @options[:drb] = drb
-          end
-          opts.on("--port PORT", "Specify DRb port.  Ignored without --drb") do |port|
-            @options[:drb_port] = port
-          end
-          opts.on("--dotcucumber DIR", "Write metadata to DIR") do |dir|
-            @options[:dotcucumber] = dir
+          opts.on("--order TYPE[:SEED]", "Run examples in the specified order. Available types:",
+            *<<-TEXT.split("\n")) do |order|
+  [defined]     Run scenarios in the order they were defined (default).
+  [random]      Shuffle scenarios before running.
+Specify SEED to reproduce the shuffling from a previous run.
+  e.g. --order random:5738
+TEXT
+            @options[:order], @options[:seed] = *order.split(":")
+            unless ORDER_TYPES.include?(@options[:order])
+              fail "'#{@options[:order]}' is not a recognised order type. Please use one of #{ORDER_TYPES.join(", ")}."
+            end
           end
           opts.on_tail("--version", "Show version.") do
             @out_stream.puts Cucumber::VERSION
@@ -311,7 +273,7 @@ module Cucumber
       end
 
       def filters
-        @options.values_at(:name_regexps, :tag_expressions).select{|v| !v.empty?}.first || []
+        @options[:filters] ||= []
       end
 
     protected
