@@ -1,24 +1,35 @@
+require 'cucumber/core/test/result'
+
 module Cucumber
   # Raised when there is no matching StepDefinition for a step.
-  class Undefined < StandardError
-    attr_reader :step_name
+  class Undefined < Core::Test::Result::Undefined
+    def self.from(result, step_name)
+      if result.is_a?(self)
+        return result.with_message(with_prefix(result.message))
+      end
 
+      begin
+        raise self.new(with_prefix(step_name))
+      rescue => exception
+        return exception
+      end
+    end
+
+    def self.with_prefix(step_name)
+      %(Undefined step: "#{step_name}")
+    end
+  end
+
+  # Raised when there is no matching StepDefinition for a step called
+  # from within another step definition.
+  class UndefinedDynamicStep < StandardError
     def initialize(step_name)
-      super %{Undefined step: "#{step_name}"}
-      @step_name = step_name
-    end
-
-    def nested!
-      @nested = true
-    end
-
-    def nested?
-      @nested
+      super %(Undefined dynamic step: "#{step_name}")
     end
   end
 
   # Raised when a StepDefinition's block invokes World#pending
-  class Pending < StandardError
+  class Pending < Core::Test::Result::Pending
   end
 
   # Raised when a step matches 2 or more StepDefinitions
