@@ -10,6 +10,8 @@ module Cucumber
         @gf = gherkin_formatter
         @print_empty_match = print_empty_match
         @options = options
+        @delayed_messages = []
+        @delayed_embeddings = []
       end
 
       def before_feature(feature)
@@ -24,10 +26,10 @@ module Cucumber
 
       def before_feature_element(feature_element)
         case(feature_element)
-        when Ast::Scenario
+        when Core::Ast::Scenario
           @outline = false
           @gf.scenario(feature_element.gherkin_statement)
-        when Ast::ScenarioOutline
+        when Core::Ast::ScenarioOutline
           @outline = true
           if @options[:expand]
             @in_instantiated_scenario = false
@@ -40,6 +42,10 @@ module Cucumber
         end
       end
 
+      def before_test_case(test_case)
+        @delay_output = true
+      end
+
       def scenario_name(keyword, name, file_colon_line, source_indent)
         if @outline and @options[:expand]
           return if not @in_instantiated_scenario
@@ -65,9 +71,12 @@ module Cucumber
       def before_step(step)
         unless @outline and @options[:expand]
           @gf.step(step.gherkin_statement)
+          pass_delayed_output
+          @delay_output = false
         else 
           if @in_instantiated_scenario
             @current_step_hash = to_hash(step.gherkin_statement)
+            @delay_output = true
           end
         end
         if @print_empty_match
@@ -78,7 +87,6 @@ module Cucumber
           end
           @gf.match(match)
         end
-        @step_time = Time.now
       end
 
       def before_step_result(keyword, step_match, multiline_arg, status, exception, source_indent, background, file_colon_line)
@@ -111,9 +119,11 @@ module Cucumber
               @current_step_hash['comments'],
               @current_step_hash['keyword'],
               step_match.format_args(),
-              @current_step_hash['line'],
+              file_colon_line.split(':')[1].to_i,
               @current_step_hash['rows'],
               @current_step_hash['doc_string']))
+          pass_delayed_output
+          @delay_output = false
           @gf.match(@current_match)
           @gf.result(@current_result)
         end
@@ -131,9 +141,8 @@ module Cucumber
 
       #used for capturing duration
       def after_step(step)
-        step_finish = (Time.now - @step_time)
         unless @outline and @options[:expand] and not @in_instantiated_scenario
-          @gf.append_duration(step_finish)
+          step.duration.tap { |duration| @gf.append_duration(duration.nanoseconds / 10 ** 9.0) }
         end
       end
 
@@ -159,11 +168,19 @@ module Cucumber
         if defined?(JRUBY_VERSION)
           data = data.to_java_bytes
         end
-        @gf.embedding(mime_type, data)
+        unless @delay_output
+          @gf.embedding(mime_type, data)
+        else
+          @delayed_embeddings.push [mime_type, data]
+        end
       end
 
       def puts(message)
-        @gf.write(message)
+        unless @delay_output
+          @gf.write(message)
+        else
+          @delayed_messages.push message
+        end
       end
 
       private
@@ -175,6 +192,13 @@ module Cucumber
           gherkin_statement.to_hash
         end
       end
+
+      def pass_delayed_output
+        @delayed_messages.each { |message| @gf.write(message) }
+        @delayed_embeddings.each { |embed_data| @gf.embedding(embed_data[0], embed_data[1]) }
+        @delayed_messages = []
+        @delayed_embeddings = []
+      end
     end
   end
 end
