@@ -1,11 +1,20 @@
 require 'erb'
-require 'cucumber/formatter/ordered_xml_markup'
+require 'builder'
 require 'cucumber/formatter/duration'
 require 'cucumber/formatter/io'
+require 'pathname'
 
 module Cucumber
   module Formatter
     class Html
+
+      # TODO: remove coupling to types
+      AST_CLASSES = {
+        Cucumber::Core::Ast::Scenario        => 'scenario',
+        Cucumber::Core::Ast::ScenarioOutline => 'scenario outline'
+      }
+      AST_DATA_TABLE = LegacyApi::Ast::MultilineArg::DataTable
+
       include ERB::Util # for the #h method
       include Duration
       include Io
@@ -22,7 +31,9 @@ module Cucumber
         @header_red = nil
         @delayed_messages = []
         @img_id = 0
+        @text_id = 0
         @inside_outline = false
+        @previous_step_keyword = nil
       end
 
       def embed(src, mime_type, label)
@@ -33,21 +44,35 @@ module Cucumber
             src = "data:" + type + "," + src
           end
           embed_image(src, label)
+        when /^text\/plain/
+          embed_text(src, label)
         end
       end
 
       def embed_image(src, label)
         id = "img_#{@img_id}"
         @img_id += 1
+        if @io.respond_to?(:path) and File.file?(src)
+          out_dir = Pathname.new(File.dirname(File.absolute_path(@io.path)))
+          src = Pathname.new(File.absolute_path(src)).relative_path_from(out_dir)
+        end        
         @builder.span(:class => 'embed') do |pre|
           pre << %{<a href="" onclick="img=document.getElementById('#{id}'); img.style.display = (img.style.display == 'none' ? 'block' : 'none');return false">#{label}</a><br>&nbsp;
           <img id="#{id}" style="display: none" src="#{src}"/>}
         end
       end
 
+      def embed_text(src, label)
+        id = "text_#{@text_id}"
+        @text_id += 1
+        @builder.span(:class => 'embed') do |pre|
+          pre << %{<a id="#{id}" href="#{src}" title="#{label}">#{label}</a>}
+        end
+      end
+
 
       def before_features(features)
-        @step_count = features.step_count
+        @step_count = features && features.step_count || 0 #TODO: Make this work with core!
 
         # <!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
         @builder.declare!(
@@ -136,6 +161,10 @@ module Cucumber
         end
       end
 
+      def before_test_case(test_case)
+        @previous_step_keyword = nil
+      end
+
       def before_background(background)
         @in_background = true
         @builder << '<div class="background">'
@@ -158,16 +187,18 @@ module Cucumber
       def before_feature_element(feature_element)
         @scenario_number+=1
         @scenario_red = false
-        css_class = {
-          Ast::Scenario        => 'scenario',
-          Ast::ScenarioOutline => 'scenario outline'
-        }[feature_element.class]
+        css_class = AST_CLASSES[feature_element.class]
         @builder << "<div class='#{css_class}'>"
+        @in_scenario_outline = feature_element.class == Cucumber::Core::Ast::ScenarioOutline
       end
 
       def after_feature_element(feature_element)
+        unless @in_scenario_outline
+          print_messages
+          @builder << '</ol>'
+        end
         @builder << '</div>'
-        @open_step_list = true
+        @in_scenario_outline = nil
       end
 
       def scenario_name(keyword, name, file_colon_line, source_indent)
@@ -195,7 +226,7 @@ module Cucumber
       end
 
       def before_examples(examples)
-         @builder << '<div class="examples">'
+        @builder << '<div class="examples">'
       end
 
       def after_examples(examples)
@@ -215,10 +246,12 @@ module Cucumber
       end
 
       def after_steps(steps)
-        @builder << '</ol>'
+        print_messages
+        @builder << '</ol>' if @in_background or @in_scenario_outline
       end
 
       def before_step(step)
+        print_messages
         @step_id = step.dom_id
         @step_number += 1
         @step = step
@@ -251,11 +284,15 @@ module Cucumber
       def after_step_result(keyword, step_match, multiline_arg, status, exception, source_indent, background, file_colon_line)
         return if @hide_this_step
         # print snippet for undefined steps
+        unless outline_step?(@step)
+          keyword = @step.actual_keyword(@previous_step_keyword)
+          @previous_step_keyword = keyword
+        end
         if status == :undefined
-          keyword = @step.actual_keyword if @step.respond_to?(:actual_keyword)
-          step_multiline_class = @step.multiline_arg ? @step.multiline_arg.class : nil
           @builder.pre do |pre|
-            pre << @runtime.snippet_text(keyword,step_match.instance_variable_get("@name") || '',step_multiline_class)
+            # TODO: snippet text should be an event sent to the formatter so we don't 
+            # have this couping to the runtime.
+            pre << @runtime.snippet_text(keyword,step_match.instance_variable_get("@name") || '', @step.multiline_arg)
           end
         end
         @builder << '</li>'
@@ -273,6 +310,7 @@ module Cucumber
 
       def exception(exception, status)
         return if @hide_this_step
+        print_messages
         build_exception_detail(exception)
       end
 
@@ -283,14 +321,14 @@ module Cucumber
 
       def before_multiline_arg(multiline_arg)
         return if @hide_this_step || @skip_step
-        if Ast::Table === multiline_arg
+        if AST_DATA_TABLE === multiline_arg
           @builder << '<table>'
         end
       end
 
       def after_multiline_arg(multiline_arg)
         return if @hide_this_step || @skip_step
-        if Ast::Table === multiline_arg
+        if AST_DATA_TABLE === multiline_arg
           @builder << '</table>'
         end
       end
@@ -302,7 +340,6 @@ module Cucumber
         end
       end
 
-
       def before_table_row(table_row)
         @row_id = table_row.dom_id
         @col_index = 0
@@ -538,7 +575,7 @@ module Cucumber
       end
 
       def backtrace_line(line)
-        line.gsub(/\A([^:]*\.(?:rb|feature|haml)):(\d*).*\z/) do
+        line.gsub(/^([^:]*\.(?:rb|feature|haml)):(\d*).*$/) do
           if ENV['TM_PROJECT_DIRECTORY']
             "<a href=\"txmt://open?url=file://#{File.expand_path($1)}&line=#{$2}\">#{$1}:#{$2}</a> "
           else
@@ -576,7 +613,11 @@ module Cucumber
       end
 
       def create_builder(io)
-        OrderedXmlMarkup.new(:target => io, :indent => 0)
+        Builder::XmlMarkup.new(:target => io, :indent => 0)
+      end
+
+      def outline_step?(step)
+        not @step.step.respond_to?(:actual_keyword)
       end
 
       class SnippetExtractor #:nodoc:
