@@ -1,4 +1,6 @@
 require 'forwardable'
+require 'cucumber/core/ast/doc_string'
+require 'cucumber/core/ast/data_table'
 
 module Cucumber
   class Runtime
@@ -21,11 +23,11 @@ module Cucumber
         :step_match
 
       def_delegators :@support_code,
-        :invoke_steps,
-        :invoke,
+        :invoke_dynamic_steps,
+        :invoke_dynamic_step,
         :load_programming_language
 
-      # Returns a Cucumber::Ast::Table for +text_or_table+, which can either
+      # Returns a Cucumber::MultilineArgument::DataTable for +text_or_table+, which can either
       # be a String:
       #
       #   table(%{
@@ -42,18 +44,20 @@ module Cucumber
       #     %w{ CUC-101 Peeler      22     }
       #   ])
       #
-      def table(text_or_table, file=nil, line_offset=0)
-        if Array === text_or_table
-          Ast::Table.new(text_or_table)
+      def table(text_or_table, file=nil, line=0)
+        if !file
+          location = Core::Ast::Location.of_caller
         else
-          Ast::Table.parse(text_or_table, file, line_offset)
+          location = Core::Ast::Location.new(file, line)
         end
+        MultilineArgument::DataTable.from(text_or_table, location)
       end
 
-      # Returns Ast::DocString for +string_without_triple_quotes+.
+      # Returns a Cucumber::MultilineArgument::DocString for +body+.
       #
-      def doc_string(string_without_triple_quotes, content_type='', line_offset=0)
-        Ast::DocString.new(string_without_triple_quotes,content_type)
+      def doc_string(body, content_type='', line_offset=0)
+        location = Core::Ast::Location.of_caller
+        MultilineArgument.doc_string(body, content_type, location)
       end
     end
   end
