@@ -1,19 +1,14 @@
-ENV['CUCUMBER_COLORS']=nil
-$:.unshift(File.dirname(__FILE__) + '/../lib')
+ENV['CUCUMBER_COLORS'] = nil
 $:.unshift(File.dirname(__FILE__))
 
 # For Travis....
-if defined? Encoding
-  Encoding.default_external = 'utf-8'
-  Encoding.default_internal = 'utf-8'
-end
+require 'cucumber/encoding'
 
-require 'rubygems'
-require 'bundler'
-Bundler.setup
+load File.expand_path(File.dirname(__FILE__) + '/../spec/simplecov_setup.rb')
+
+require 'pry'
 
 require 'cucumber'
-$KCODE='u' if Cucumber::RUBY_1_8_7
 
 RSpec.configure do |c|
   c.before do
@@ -23,7 +18,7 @@ end
 
 module RSpec
   module WorkInProgress
-    def pending_under platforms, reason, &block
+    def pending_under(platforms, reason, &block)
       if [platforms].flatten.map(&:to_s).include? RUBY_PLATFORM
         pending "pending under #{platforms.inspect} because: #{reason}", &block
       else
@@ -32,5 +27,3 @@ module RSpec
     end
   end
 end
-
-
